"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.buildLambdas = exports.getOutFileForLambda = exports.getOutDirForLambda = void 0;
const esbuild_1 = require("esbuild");
const esbuild_plugin_pnp_1 = require("@yarnpkg/esbuild-plugin-pnp");
const utils_aws_lambda_1 = require("@goldstack/utils-aws-lambda");
const utils_sh_1 = require("@goldstack/utils-sh");
const getOutDirForLambda = (config) => {
    if (config.path === '$default') {
        return `./distLambda/${config.path}`;
    }
    return `./distLambda${config.path}`;
};
exports.getOutDirForLambda = getOutDirForLambda;
const getOutFileForLambda = (config) => {
    return `${(0, exports.getOutDirForLambda)(config)}/lambda.js`;
};
exports.getOutFileForLambda = getOutFileForLambda;
const buildLambdas = async ({ routesDir, configs, lambdaNamePrefix, }) => {
    const esbuildConfig = (0, utils_sh_1.readToType)('./esbuild.config.json');
    await (0, utils_sh_1.rmSafe)('./distLambda');
    (0, utils_sh_1.mkdir)('-p', './distLambda/zips');
    for await (const config of configs) {
        (0, utils_sh_1.mkdir)('-p', (0, exports.getOutDirForLambda)(config));
        const esbuildLocalPath = (0, utils_sh_1.changeExtension)(`${routesDir}/${config.relativeFilePath}`, '.esbuild.config.json');
        const functionName = (0, utils_aws_lambda_1.generateFunctionName)(lambdaNamePrefix, config);
        const localEsbuildConfig = (0, utils_sh_1.readToType)(esbuildLocalPath);
        const res = await (0, esbuild_1.build)({
            plugins: [(0, esbuild_plugin_pnp_1.pnpPlugin)()],
            bundle: true,
            entryPoints: [`${routesDir}/${config.relativeFilePath}`],
            external: [
                'aws-sdk', // included in Lambda runtime environment
            ],
            minify: true,
            platform: 'node',
            format: 'cjs',
            target: 'node16.0',
            treeShaking: true,
            sourcemap: true,
            outfile: (0, exports.getOutFileForLambda)(config),
            metafile: true,
            ...esbuildConfig,
            ...localEsbuildConfig,
        });
        if (!res.metafile) {
            throw new Error(`Metafile for ${functionName} not defined.`);
        }
        (0, utils_sh_1.write)(JSON.stringify(res.metafile), `./distLambda/zips/${functionName}.meta.json`);
    }
};
exports.buildLambdas = buildLambdas;
//# sourceMappingURL=templateLambdaApiBuild.js.map